@@ -49,7 +49,7 @@ else:
         return ' '.join(map(pipes.quote, cmd_list))
 
 
-__version__ = '0.7.6'
+__version__ = '0.7.10'
 
 # ---------------------------------------------------------------------------
 # Top Level Variables
@@ -377,7 +377,8 @@ def install_npm(path=None, build_dir=None, source_dir=None, build_cmd='build',
                 log.info('Installing build dependencies with npm.  This may '
                          'take a while...')
                 run(npm_cmd + ['install'], cwd=node_package)
-                run(npm_cmd + ['run', build_cmd], cwd=node_package)
+                if build_cmd:
+                    run(npm_cmd + ['run', build_cmd], cwd=node_package)
 
     return NPM
 
@@ -405,10 +406,10 @@ def ensure_targets(targets):
 def skip_if_exists(paths, CommandClass):
     """Skip a command if list of paths exists."""
     def should_skip():
-        return any(not Path(path).exist() for path in paths)
+        return all(Path(path).exists() for path in paths)
     class SkipIfExistCommand(Command):
         def initialize_options(self):
-            if not should_skip:
+            if not should_skip():
                 self.command = CommandClass(self.distribution)
                 self.command.initialize_options()
             else:
@@ -592,7 +593,7 @@ def _get_data_files(data_specs, existing, *, top=None, exclude=None):
         if os.path.isabs(dname):
             dname = os.path.relpath(dname, top)
 
-        dname = dname.replace(os.sep, '/')
+        dname = dname.replace(os.sep, '/').rstrip('/')
         offset = 0 if dname in ('.', '') else len(dname) + 1
         files = _get_files(_glob_pjoin(dname, pattern), top=top)
 
